@@ -34,11 +34,16 @@
 #include "umllistview.h"
 
 //kde includes
+#if QT_VERSION < 0x050000
 #include <kfiledialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
 
 //qt includes
+#if QT_VERSION >= 0x050000
+#include <QFileDialog>
+#endif
 #include <QListWidget>
 #include <QTimer>
 
@@ -327,7 +332,11 @@ void CodeImpStatusPage::loggerClear()
 void CodeImpStatusPage::loggerExport()
 {
     const QString caption = i18n("Umbrello Code Import - Logger Export");
+#if QT_VERSION >= 0x050000
+    QString fileName = QFileDialog::getSaveFileName(wizard(), caption);
+#else
     QString fileName = KFileDialog::getSaveFileName(KUrl(), QString(), 0, caption);
+#endif
     if (!fileName.isEmpty()) {
         QFile file(fileName);
         if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
@@ -341,4 +350,3 @@ void CodeImpStatusPage::loggerExport()
     }
 }
 
-#include "codeimpstatuspage.moc"
